
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.6.7',
    'branch_nick': '(no',
    'revision_id': 'a8eafd9de3c03090914f43019ffa927b687525df',
    'revno': 4141
}
